==> pysolfc-2.10.1-2-any.pkg.tar.zst: usr/lib/python3.9/site-packages/pysollib/games/__init__.py <==
#!/usr/bin/env python
# -*- mode: python; coding: utf-8; -*-
# ---------------------------------------------------------------------------##
#
# Copyright (C) 1998-2003 Markus Franz Xaver Johannes Oberhumer
# Copyright (C) 2003 Mt. Hood Playing Card Co.
# Copyright (C) 2005-2009 Skomoroh
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.
#
# ---------------------------------------------------------------------------##
from . import acesup  # noqa: F401
from . import algerian  # noqa: F401
from . import auldlangsyne  # noqa: F401
from . import bakersdozen  # noqa: F401
from . import bakersgame  # noqa: F401
from . import beleagueredcastle  # noqa: F401
from . import bisley  # noqa: F401
from . import bisley13  # noqa: F401
from . import braid  # noqa: F401
from . import bristol  # noqa: F401
from . import buffalobill  # noqa: F401
from . import calculation  # noqa: F401
from . import camelot  # noqa: F401
from . import canfield  # noqa: F401
from . import capricieuse  # noqa: F401
from . import curdsandwhey  # noqa: F401
from . import daddylonglegs  # noqa: F401
from . import dieboesesieben  # noqa: F401
from . import diplomat  # noqa: F401
from . import doublets  # noqa: F401
from . import eiffeltower  # noqa: F401
from . import fan  # noqa: F401
from . import fortythieves  # noqa: F401
from . import freecell  # noqa: F401
from . import glenwood  # noqa: F401
from . import golf  # noqa: F401
from . import grandduchess  # noqa: F401
from . import grandfathersclock  # noqa: F401
from . import gypsy  # noqa: F401
from . import harp  # noqa: F401
from . import headsandtails  # noqa: F401
from . import katzenschwanz  # noqa: F401
from . import klondike  # noqa: F401
from . import labyrinth  # noqa: F401
from . import larasgame  # noqa: F401
from . import matriarchy  # noqa: F401
from . import montana  # noqa: F401
from . import montecarlo  # noqa: F401
from . import napoleon  # noqa: F401
from . import needle  # noqa: F401
from . import numerica  # noqa: F401
from . import osmosis  # noqa: F401
from . import parallels  # noqa: F401
from . import pasdedeux  # noqa: F401
from . import picturegallery  # noqa: F401
from . import pileon  # noqa: F401
from . import pushpin  # noqa: F401
from . import pyramid  # noqa: F401
from . import royalcotillion  # noqa: F401
from . import royaleast  # noqa: F401
from . import sanibel  # noqa: F401
from . import siebenbisas  # noqa: F401
from . import simplex  # noqa: F401
from . import spider  # noqa: F401
from . import sthelena  # noqa: F401
from . import sultan  # noqa: F401
from . import takeaway  # noqa: F401
from . import terrace  # noqa: F401
from . import threepeaks  # noqa: F401
from . import tournament  # noqa: F401
from . import unionsquare  # noqa: F401
from . import wavemotion  # noqa: F401
from . import windmill  # noqa: F401
from . import yukon  # noqa: F401
from . import zodiac  # noqa: F401

==> pysolfc-3.4.1-1-any.pkg.tar.zst: usr/lib/python3.13/site-packages/pysollib/games/__init__.py <==
#!/usr/bin/env python
# -*- mode: python; coding: utf-8; -*-
# ---------------------------------------------------------------------------##
#
# Copyright (C) 1998-2003 Markus Franz Xaver Johannes Oberhumer
# Copyright (C) 2003 Mt. Hood Playing Card Co.
# Copyright (C) 2005-2009 Skomoroh
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.
#
# ---------------------------------------------------------------------------##
from . import acesandkings  # noqa: F401
from . import acesup  # noqa: F401
from . import algerian  # noqa: F401
from . import auldlangsyne  # noqa: F401
from . import bakersdozen  # noqa: F401
from . import bakersgame  # noqa: F401
from . import beleagueredcastle  # noqa: F401
from . import bisley  # noqa: F401
from . import bisley13  # noqa: F401
from . import braid  # noqa: F401
from . import bristol  # noqa: F401
from . import buffalobill  # noqa: F401
from . import calculation  # noqa: F401
from . import camelot  # noqa: F401
from . import canfield  # noqa: F401
from . import capricieuse  # noqa: F401
from . import clearthedungeon  # noqa: F401
from . import crossword  # noqa: F401
from . import curdsandwhey  # noqa: F401
from . import daddylonglegs  # noqa: F401
from . import demonsandthieves  # noqa: F401
from . import dieboesesieben  # noqa: F401
from . import diplomat  # noqa: F401
from . import doublets  # noqa: F401
from . import eiffeltower  # noqa: F401
from . import fan  # noqa: F401
from . import fortythieves  # noqa: F401
from . import freecell  # noqa: F401
from . import glenwood  # noqa: F401
from . import golf  # noqa: F401
from . import grandduchess  # noqa: F401
from . import grandfathersclock  # noqa: F401
from . import gypsy  # noqa: F401
from . import harp  # noqa: F401
from . import headsandtails  # noqa: F401
from . import hitormiss  # noqa: F401
from . import interlock  # noqa: F401
from . import katzenschwanz  # noqa: F401
from . import klondike  # noqa: F401
from . import knockout  # noqa: F401
from . import labyrinth  # noqa: F401
from . import larasgame  # noqa: F401
from . import matriarchy  # noqa: F401
from . import montana  # noqa: F401
from . import montecarlo  # noqa: F401
from . import moojub  # noqa: F401
from . import napoleon  # noqa: F401
from . import needle  # noqa: F401
from . import numerica  # noqa: F401
from . import osmosis  # noqa: F401
from . import parallels  # noqa: F401
from . import pasdedeux  # noqa: F401
from . import picturegallery  # noqa: F401
from . import pileon  # noqa: F401
from . import precedence  # noqa: F401
from . import pushpin  # noqa: F401
from . import pyramid  # noqa: F401
from . import royalcotillion  # noqa: F401
from . import royaleast  # noqa: F401
from . import sanibel  # noqa: F401
from . import siebenbisas  # noqa: F401
from . import simplex  # noqa: F401
from . import spider  # noqa: F401
from . import sthelena  # noqa: F401
from . import sultan  # noqa: F401
from . import takeaway  # noqa: F401
from . import terrace  # noqa: F401
from . import threepeaks  # noqa: F401
from . import tournament  # noqa: F401
from . import unionsquare  # noqa: F401
from . import wavemotion  # noqa: F401
from . import windmill  # noqa: F401
from . import yukon  # noqa: F401
from . import zodiac  # noqa: F401
